@@ -34,8 +34,6 @@ import sys
 
 
 class grammarSemantics(object):
-#    def __init__(self):
-#        self._protocol = None
 
     def start(self, ast):
         return ast
@@ -89,7 +87,7 @@ class grammarSemantics(object):
                 try:
                     file_h = open(include).read().splitlines()
                 except IOError:
-                    print "could not open file: %s" % include
+                    print "ERROR: could not open file: %s" % include
                     sys.exit(2)
                 for line in file_h:
                     if line.startswith('@'):
@@ -152,7 +150,7 @@ class grammarSemantics(object):
                 try:
                     file_h = open(include).read().splitlines()
                 except IOError:
-                    print "could not open file: %s" % include
+                    print "ERROR: could not open file: %s" % include
                     import os
                     print os.getcwd()
                     sys.exit(2)
@@ -185,7 +183,7 @@ class grammarSemantics(object):
                 try:
                     file_h = open(include).read().splitlines()
                 except IOError:
-                    print "could not open file: %s" % include
+                    print "ERROR: could not open file: %s" % include
                     sys.exit(2)
                 for line in file_h:
                     if line.startswith('@'):
