@@ -41,6 +41,7 @@ The following process is followed to ensure zero impact
 
 from Exscript.util.interact import read_login
 from Exscript.protocols import SSH2, Telnet, Account
+from Exscript.protocols.Exception import LoginFailure
 
 import netrc
 
@@ -49,7 +50,7 @@ from aclhound import textfsm
 from StringIO import StringIO
 
 
-def deploy(hostname=None, acls=None):
+def deploy(hostname=None, acls=None, transport='ssh'):
     """
     Deploy code in a safe way o a Cisco IOS device.
     """
@@ -90,10 +91,22 @@ Start
         return map_acl_int
 
     # main flow of the program starts here
-    conn = SSH2(verify_fingerprint=False, debug=0)
+    if transport == 'ssh':
+        conn = SSH2(verify_fingerprint=False, debug=0)
+    elif transport == 'telnet':
+        conn = Telnet(debug=0)
+    else:
+        print("ERROR: Unknown transport mechanism: %s" %
+              transport)
+        sys.exit(2)
     conn.set_driver('ios')
     conn.connect(hostname)
-    conn.login(account)
+    try:
+        conn.login(account)
+    except LoginFailure:
+        print("ERROR: Username or Password incorrect for %s" % hostname)
+        print("HINT: verify authentication details in your .netrc file")
+        sys.exit(2)
 
     map_pol_int = collect_interfaces(conn)
     pprint(map_pol_int)
